==> ciscoconfparse-1.5.49-py3-none-any.whl: ciscoconfparse/__init__.py <==

from ciscoconfparse.ciscoconfparse import __author_email__
from ciscoconfparse.ciscoconfparse import __author__
from ciscoconfparse.ciscoconfparse import __license__
from ciscoconfparse.ciscoconfparse import __version__
from ciscoconfparse.ciscoconfparse import *
from ciscoconfparse.ccp_util import *

""" __init__.py - Parse, Query, Build, and Modify IOS-style configurations

     Copyright (C) 2020-2021 Cisco Systems and David Michael Pennington
     Copyright (C) 2019      ThousandEyes and David Michael Pennington
     Copyright (C) 2012-2019 Samsung Data Services and David Michael Pennington
     Copyright (C) 2011-2012 Dell Computer Corp. and David Michael Pennington
     Copyright (C) 2007-2011 David Michael Pennington and David Michael Pennington

     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.

     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.

     If you need to contact the author, you can do so by emailing:
     mike [~at~] pennington [/dot\] net
"""

==> ciscoconfparse-1.6.4-py3-none-any.whl: ciscoconfparse/__init__.py <==

from ciscoconfparse.ciscoconfparse import __author_email__
from ciscoconfparse.ciscoconfparse import __author__
from ciscoconfparse.ciscoconfparse import __license__
from ciscoconfparse.ciscoconfparse import __version__
from ciscoconfparse.ciscoconfparse import *
from ciscoconfparse.ccp_util import *

r""" __init__.py - Parse, Query, Build, and Modify IOS-style configurations

     Copyright (C) 2020-2021 David Michael Pennington at Cisco Systems
     Copyright (C) 2019      David Michael Pennington at ThousandEyes
     Copyright (C) 2012-2019 David Michael Pennington at Samsung Data Services
     Copyright (C) 2011-2012 David Michael Pennington at Dell Computer Corp.
     Copyright (C) 2007-2011 David Michael Pennington

     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.

     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.

     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.

     If you need to contact the author, you can do so by emailing:
     mike [~at~] pennington [/dot\] net
"""
